@@ -69,21 +69,15 @@ describe 'horizon' do
           "    'can_set_mount_point': True,",
           "    'can_set_password': False,",
           "    'enable_distributed_router': False,",
-          "    'enable_firewall': False,",
           "    'enable_ha_router': False,",
-          "    'enable_lb': False,",
           "    'enable_quotas': True,",
           "    'enable_security_group': True,",
-          "    'enable_vpn': False,",
           'API_RESULT_LIMIT = 1000',
           'DROPDOWN_MAX_ITEMS = 30',
           'TIME_ZONE = "UTC"',
           "            'handlers': ['file'],",
           'COMPRESS_OFFLINE = True',
           "FILE_UPLOAD_TEMP_DIR = '/tmp'",
-          "OPENSTACK_HEAT_STACK = {",
-          "    'enable_user_pass': True",
-          "}",
         ])
 
         # From internals of verify_contents, get the contents to check for absence of a line
@@ -118,8 +112,7 @@ describe 'horizon' do
           :hypervisor_options             => {'can_set_mount_point' => false, 'can_set_password' => true },
           :cinder_options                 => {'enable_backup' => true },
           :keystone_options               => {'name' => 'native', 'can_edit_user' => true, 'can_edit_group' => true, 'can_edit_project' => true, 'can_edit_domain' => false, 'can_edit_role' => false},
-          :neutron_options                => {'enable_lb' => true, 'enable_firewall' => true, 'enable_quotas' => false, 'enable_security_group' => false, 'enable_vpn' => true,
-                                            'enable_distributed_router' => false, 'enable_ha_router' => false, 'profile_support' => 'cisco',
+          :neutron_options                => {'enable_quotas' => false, 'enable_security_group' => false, 'enable_distributed_router' => false, 'enable_ha_router' => false,
                                             'supported_provider_types' => ['flat', 'vxlan'], 'supported_vnic_types' => ['*'], 'default_ipv4_subnet_pool_label' => 'None', },
           :instance_options               => {'disable_image' => true, 'disable_instance_snapshot' => true, 'disable_volume' => true, 'disable_volume_snapshot' => true, 'create_volume' => false },
           :file_upload_temp_dir           => '/var/spool/horizon',
@@ -142,6 +135,7 @@ describe 'horizon' do
           :create_image_defaults          => {'image_visibility' => 'private'},
           :password_retrieve              => true,
           :enable_secure_proxy_ssl_header => true,
+          :secure_proxy_addr_header       => 'HTTP_X_FORWARDED_FOR',
         })
       end
 
@@ -151,6 +145,7 @@ describe 'horizon' do
           "SITE_BRANDING = 'mysite'",
           "ALLOWED_HOSTS = ['some.host.tld', ]",
           "SECURE_PROXY_SSL_HEADER = ('HTTP_X_FORWARDED_PROTO', 'https')",
+          "SECURE_PROXY_ADDR_HEADER = 'HTTP_X_FORWARDED_FOR'",
           'CSRF_COOKIE_SECURE = True',
           'SESSION_COOKIE_SECURE = True',
           'SESSION_COOKIE_HTTPONLY = True',
@@ -181,12 +176,8 @@ describe 'horizon' do
           "    'can_set_password': True,",
           "    'enable_backup': True,",
           "    'default_ipv4_subnet_pool_label': None,",
-          "    'enable_firewall': True,",
-          "    'enable_lb': True,",
           "    'enable_quotas': False,",
           "    'enable_security_group': False,",
-          "    'enable_vpn': True,",
-          "    'profile_support': 'cisco',",
           "    'supported_provider_types': ['flat', 'vxlan'],",
           "    'supported_vnic_types': ['*'],",
           'OPENSTACK_ENABLE_PASSWORD_RETRIEVE = True',
@@ -215,28 +206,17 @@ describe 'horizon' do
           'COMPRESS_OFFLINE = False',
           "FILE_UPLOAD_TEMP_DIR = '/var/spool/horizon'",
           "OVERVIEW_DAYS_RANGE = 1",
+          'DISALLOW_IFRAME_EMBED = True',
         ])
       end
 
+      it { is_expected.to contain_file(platforms_params[:conf_d_dir]).with_ensure('directory') }
       it { is_expected.not_to contain_file(platforms_params[:config_file]).that_notifies('Exec[refresh_horizon_django_cache]') }
       it { is_expected.not_to contain_file(platforms_params[:config_file]).that_notifies('Exec[refresh_horizon_django_compress]') }
 
       it { is_expected.to contain_file(params[:file_upload_temp_dir]) }
     end
 
-    context 'with enable_user_pass disabled' do
-      before do
-        params.merge!({ :enable_user_pass => false })
-      end
-      it {
-        verify_concat_fragment_contents(catalogue, 'local_settings.py', [
-          "OPENSTACK_HEAT_STACK = {",
-          "    'enable_user_pass': False",
-          "}",
-        ])
-      }
-    end
-
     context 'with overridden parameters and cache_server_ip array' do
       before do
         params.merge!({
@@ -345,21 +325,23 @@ describe 'horizon' do
     context 'with ssl enabled' do
       before do
         params.merge!({
-          :listen_ssl   => true,
-          :servername   => 'some.host.tld',
-          :horizon_cert => '/etc/pki/tls/certs/httpd.crt',
-          :horizon_key  => '/etc/pki/tls/private/httpd.key',
-          :horizon_ca   => '/etc/pki/tls/certs/ca.crt',
+          :listen_ssl        => true,
+          :servername        => 'some.host.tld',
+          :ssl_cert          => '/etc/pki/tls/certs/httpd.crt',
+          :ssl_key           => '/etc/pki/tls/private/httpd.key',
+          :ssl_ca            => '/etc/pki/tls/certs/ca.crt',
+          :ssl_verify_client => 'optional',
         })
       end
 
       it 'configures apache' do
         is_expected.to contain_class('horizon::wsgi::apache').with({
-          :bind_address => nil,
-          :listen_ssl   => true,
-          :horizon_cert => '/etc/pki/tls/certs/httpd.crt',
-          :horizon_key  => '/etc/pki/tls/private/httpd.key',
-          :horizon_ca   => '/etc/pki/tls/certs/ca.crt',
+          :bind_address      => nil,
+          :listen_ssl        => true,
+          :ssl_cert          => '/etc/pki/tls/certs/httpd.crt',
+          :ssl_key           => '/etc/pki/tls/private/httpd.key',
+          :ssl_ca            => '/etc/pki/tls/certs/ca.crt',
+          :ssl_verify_client => 'optional',
         })
       end
     end
@@ -576,16 +558,16 @@ describe 'horizon' do
       end
     end
 
-    context 'with disallow iframe embed enabled' do
+    context 'with disallow iframe embed disabled' do
       before do
         params.merge!({
-                        :disallow_iframe_embed => true
+                        :disallow_iframe_embed => false
                       })
       end
 
       it 'disallow_iframe_embed is configured' do
         verify_concat_fragment_contents(catalogue, 'local_settings.py', [
-                                          'HORIZON_CONFIG["disallow_iframe_embed"] = True',
+                                          'DISALLOW_IFRAME_EMBED = False',
                                         ])
       end
     end
@@ -593,32 +575,51 @@ describe 'horizon' do
     context 'with websso enabled' do
       before do
         params.merge!({
-                        :websso_enabled => 'True',
-                        :websso_initial_choice => 'acme',
-                        :websso_choices => [
-                          ['oidc', 'OpenID Connect'],
-                          ['saml2', 'Security Assertion Markup Language'],
-                        ],
-                        :websso_idp_mapping => {
-                          'acme_oidc'  => ['acme', 'oidc'],
-                          'acme_saml2' => ['acme', 'saml2'],
-                        }
-                      })
+            :websso_enabled => 'True',
+            :websso_initial_choice => 'acme',
+            :websso_choices => [
+              ['oidc', 'OpenID Connect'],
+              ['saml2', 'Security Assertion Markup Language'],
+            ],
+            :websso_idp_mapping => {
+              'acme_oidc'  => ['acme', 'oidc'],
+              'acme_saml2' => ['acme', 'saml2'],
+            }
+          })
       end
       it 'configures websso options' do
         verify_concat_fragment_contents(catalogue, 'local_settings.py', [
-                                          'WEBSSO_ENABLED = True',
-                                          'WEBSSO_INITIAL_CHOICE = "acme"',
-                                          'WEBSSO_CHOICES = (',
-                                          '    ("credentials", _("Keystone Credentials")),',
-                                          '    ("oidc", _("OpenID Connect")),',
-                                          '    ("saml2", _("Security Assertion Markup Language")),',
-                                          ')',
-                                          'WEBSSO_IDP_MAPPING = {',
-                                          '    "acme_oidc": ("acme", "oidc"),',
-                                          '    "acme_saml2": ("acme", "saml2"),',
-                                          '}',
-                                        ])
+          'WEBSSO_ENABLED = True',
+          'WEBSSO_INITIAL_CHOICE = "acme"',
+          'WEBSSO_CHOICES = (',
+          '    ("credentials", _("Keystone Credentials")),',
+          '    ("oidc", _("OpenID Connect")),',
+          '    ("saml2", _("Security Assertion Markup Language")),',
+          ')',
+          'WEBSSO_IDP_MAPPING = {',
+          '    "acme_oidc": ("acme", "oidc"),',
+          '    "acme_saml2": ("acme", "saml2"),',
+          '}',
+          ])
+      end
+    end
+
+    context 'with websso redirect enabled' do
+      before do
+        params.merge!({
+          :websso_default_redirect          => true,
+          :websso_default_redirect_protocol => 'oidc',
+          :websso_default_redirect_region   => 'http://127.0.0.1:5000',
+          :websso_default_redirect_logout   => 'http://idptest/logout'
+        })
+      end
+      it 'configures websso redirect options' do
+        verify_concat_fragment_contents(catalogue, 'local_settings.py', [
+          'WEBSSO_DEFAULT_REDIRECT = True',
+          'WEBSSO_DEFAULT_REDIRECT_PROTOCOL = "oidc"',
+          'WEBSSO_DEFAULT_REDIRECT_REGION = "http://127.0.0.1:5000"',
+          'WEBSSO_DEFAULT_REDIRECT_LOGOUT = "http://idptest/logout"'
+          ])
       end
     end
 
@@ -752,6 +753,7 @@ describe 'horizon' do
         when 'Debian'
           if facts[:os_package_type] == 'debian'
             { :config_file      => '/etc/openstack-dashboard/local_settings.py',
+              :conf_d_dir       => '/etc/openstack-dashboard/local_settings.d',
               :package_name     => 'openstack-dashboard-apache',
               :root_url         => '/horizon',
               :root_path        => '/var/lib/openstack-dashboard',
@@ -759,6 +761,7 @@ describe 'horizon' do
             }
           else
             { :config_file      => '/etc/openstack-dashboard/local_settings.py',
+              :conf_d_dir       => '/etc/openstack-dashboard/local_settings.d',
               :package_name     => 'openstack-dashboard',
               :root_url         => '/horizon',
               :root_path        => '/var/lib/openstack-dashboard',
@@ -766,30 +769,13 @@ describe 'horizon' do
             }
           end
         when 'RedHat'
-          if facts[:operatingsystem] == 'Fedora'
-            { :config_file      => '/etc/openstack-dashboard/local_settings',
-              :package_name     => 'openstack-dashboard',
-              :root_url         => '/dashboard',
-              :root_path        => '/usr/share/openstack-dashboard',
-              :memcache_package => 'python3-memcached',
-            }
-          else
-            if facts[:operatingsystemmajrelease] > '7'
-              { :config_file      => '/etc/openstack-dashboard/local_settings',
-                :package_name     => 'openstack-dashboard',
-                :root_url         => '/dashboard',
-                :root_path        => '/usr/share/openstack-dashboard',
-                :memcache_package => 'python3-memcached',
-              }
-            else
-              { :config_file      => '/etc/openstack-dashboard/local_settings',
-                :package_name     => 'openstack-dashboard',
-                :root_url         => '/dashboard',
-                :root_path        => '/usr/share/openstack-dashboard',
-                :memcache_package => 'python-memcached',
-              }
-            end
-          end
+          { :config_file      => '/etc/openstack-dashboard/local_settings',
+            :conf_d_dir       => '/etc/openstack-dashboard/local_settings.d',
+            :package_name     => 'openstack-dashboard',
+            :root_url         => '/dashboard',
+            :root_path        => '/usr/share/openstack-dashboard',
+            :memcache_package => 'python3-memcached',
+          }
         end
       end
 
