@@ -22,8 +22,6 @@ describe 'horizon::wsgi::apache' do
       it { should contain_class('horizon::params') }
       it { should contain_class('apache') }
       it { should contain_class('apache::mod::wsgi') }
-      it { should contain_service('httpd').with_name(platforms_params[:http_service]) }
-      it { should contain_package('httpd').with_name(platforms_params[:http_service]) }
       it { should contain_file(platforms_params[:httpd_config_file]) }
       it { should contain_package('horizon').with_ensure('present') }
 
@@ -46,8 +44,8 @@ describe 'horizon::wsgi::apache' do
           platforms_params[:wsgi_group] => {
             'processes'    => facts[:os_workers],
             'threads'      => '1',
-            'user'         => platforms_params[:unix_user],
-            'group'        => platforms_params[:unix_group],
+            'user'         => platforms_params[:wsgi_user],
+            'group'        => platforms_params[:wsgi_group],
             'display-name' => 'horizon'
           }},
         :wsgi_application_group      => '%{GLOBAL}',
@@ -68,8 +66,6 @@ describe 'horizon::wsgi::apache' do
       it { should contain_class('horizon::params') }
       it { should contain_class('apache') }
       it { should contain_class('apache::mod::wsgi') }
-      it { should contain_service('httpd').with_name(platforms_params[:http_service]) }
-      it { should contain_package('httpd').with_name(platforms_params[:http_service]) }
       it { should contain_file(platforms_params[:httpd_config_file]) }
       it { should contain_package('horizon').with_ensure('present') }
 
@@ -92,8 +88,8 @@ describe 'horizon::wsgi::apache' do
           platforms_params[:wsgi_group] => {
             'processes'    => '13',
             'threads'      => '3',
-            'user'         => platforms_params[:unix_user],
-            'group'        => platforms_params[:unix_group],
+            'user'         => platforms_params[:wsgi_user],
+            'group'        => platforms_params[:wsgi_group],
             'display-name' => 'horizon'
           }},
         :wsgi_application_group      => '%{GLOBAL}',
@@ -116,7 +112,7 @@ describe 'horizon::wsgi::apache' do
             'processes'    => facts[:os_workers],
             'threads'      => '1',
             'user'         => 'myuser',
-            'group'        => platforms_params[:unix_group],
+            'group'        => platforms_params[:wsgi_group],
             'display-name' => 'horizon',
             'python_path'  => '/my/python/admin/path'
           }}
@@ -126,11 +122,12 @@ describe 'horizon::wsgi::apache' do
     context 'with ssl enabled' do
       before do
         params.merge!({
-          :listen_ssl   => true,
-          :ssl_redirect => true,
-          :horizon_cert => '/etc/pki/tls/certs/httpd.crt',
-          :horizon_key  => '/etc/pki/tls/private/httpd.key',
-          :horizon_ca   => '/etc/pki/tls/certs/ca.crt',
+          :listen_ssl        => true,
+          :ssl_redirect      => true,
+          :ssl_cert          => '/etc/pki/tls/certs/httpd.crt',
+          :ssl_key           => '/etc/pki/tls/private/httpd.key',
+          :ssl_ca            => '/etc/pki/tls/certs/ca.crt',
+          :ssl_verify_client => 'optional',
         })
       end
 
@@ -149,6 +146,7 @@ describe 'horizon::wsgi::apache' do
         :ssl_cert               => '/etc/pki/tls/certs/httpd.crt',
         :ssl_key                => '/etc/pki/tls/private/httpd.key',
         :ssl_ca                 => '/etc/pki/tls/certs/ca.crt',
+        :ssl_verify_client      => 'optional',
         :redirectmatch_status   => 'permanent',
         :redirectmatch_regexp   => '^/$',
         :redirectmatch_dest     => platforms_params[:root_url],
@@ -157,8 +155,8 @@ describe 'horizon::wsgi::apache' do
           'horizon-ssl' => {
             'processes'    => facts[:os_workers],
             'threads'      => '1',
-            'user'         => platforms_params[:unix_user],
-            'group'        => platforms_params[:unix_group],
+            'user'         => platforms_params[:wsgi_user],
+            'group'        => platforms_params[:wsgi_group],
             'display-name' => 'horizon'
           }},
         :wsgi_application_group => '%{GLOBAL}',
@@ -185,8 +183,8 @@ describe 'horizon::wsgi::apache' do
           platforms_params[:wsgi_group] => {
             'processes'    => facts[:os_workers],
             'threads'      => '1',
-            'user'         => platforms_params[:unix_user],
-            'group'        => platforms_params[:unix_group],
+            'user'         => platforms_params[:wsgi_user],
+            'group'        => platforms_params[:wsgi_group],
             'display-name' => 'horizon'
           }},
         :wsgi_application_group => '%{GLOBAL}',
@@ -196,21 +194,32 @@ describe 'horizon::wsgi::apache' do
       )}
     end
 
-    context 'without horizon_cert parameter' do
+    context 'without ssl_cert parameter' do
       before do
         params.merge!( :listen_ssl => true )
       end
 
-      it { should raise_error(Puppet::Error, /The horizon_cert parameter is required when listen_ssl is true/) }
+      it { should raise_error(Puppet::Error, /The ssl_cert parameter is required when listen_ssl is true/) }
     end
 
-    context 'without horizon_key parameter' do
+    context 'without ssl_key parameter' do
       before do
-        params.merge!( :listen_ssl   => true,
-                       :horizon_cert => '/etc/pki/tls/certs/httpd.crt' )
+        params.merge!( :listen_ssl => true,
+                       :ssl_cert   => '/etc/pki/tls/certs/httpd.crt' )
       end
 
-      it { should raise_error(Puppet::Error, /The horizon_key parameter is required when listen_ssl is true/) }
+      it { should raise_error(Puppet::Error, /The ssl_key parameter is required when listen_ssl is true/) }
+    end
+
+    context 'without ssl_verify_client' do
+      before do
+        params.merge!( :listen_ssl => true,
+                       :ssl_cert   => '/etc/pki/tls/certs/httpd.crt',
+                       :ssl_key    => '/etc/pki/tls/certs/httpd.key',
+                       :ssl_ca     => '/etc/pki/tls/certs/httpd.ca' )
+      end
+
+      it { should raise_error(Puppet::Error, /The ssl_verify_client parameter is required when setting ssl_ca/) }
     end
 
     context 'with extra parameters' do
@@ -306,11 +315,12 @@ describe 'horizon::wsgi::apache' do
     context 'with listen_ssl and ssl_redirect set to true' do
       before do
         params.merge!({
-          :listen_ssl   => true,
-          :ssl_redirect => true,
-          :horizon_cert => '/etc/pki/tls/certs/httpd.crt',
-          :horizon_key  => '/etc/pki/tls/private/httpd.key',
-          :horizon_ca   => '/etc/pki/tls/certs/ca.crt',
+          :listen_ssl        => true,
+          :ssl_redirect      => true,
+          :ssl_cert          => '/etc/pki/tls/certs/httpd.crt',
+          :ssl_key           => '/etc/pki/tls/private/httpd.key',
+          :ssl_ca            => '/etc/pki/tls/certs/ca.crt',
+          :ssl_verify_client => 'optional',
         })
       end
 
@@ -328,12 +338,13 @@ describe 'horizon::wsgi::apache' do
     context 'with listen_ssl and ssl_redirect with a slash root_url' do
       before do
         params.merge!({
-          :listen_ssl   => true,
-          :ssl_redirect => true,
-          :horizon_cert => '/etc/pki/tls/certs/httpd.crt',
-          :horizon_key  => '/etc/pki/tls/private/httpd.key',
-          :horizon_ca   => '/etc/pki/tls/certs/ca.crt',
-          :root_url     => '/',
+          :listen_ssl        => true,
+          :ssl_redirect      => true,
+          :ssl_cert          => '/etc/pki/tls/certs/httpd.crt',
+          :ssl_key           => '/etc/pki/tls/private/httpd.key',
+          :ssl_ca            => '/etc/pki/tls/certs/ca.crt',
+          :ssl_verify_client => 'optional',
+          :root_url          => '/',
         })
       end
 
@@ -351,12 +362,13 @@ describe 'horizon::wsgi::apache' do
     context 'with listen_ssl and ssl_redirect with a empty root_url' do
       before do
         params.merge!({
-          :listen_ssl   => true,
-          :ssl_redirect => true,
-          :horizon_cert => '/etc/pki/tls/certs/httpd.crt',
-          :horizon_key  => '/etc/pki/tls/private/httpd.key',
-          :horizon_ca   => '/etc/pki/tls/certs/ca.crt',
-          :root_url     => '',
+          :listen_ssl        => true,
+          :ssl_redirect      => true,
+          :ssl_cert          => '/etc/pki/tls/certs/httpd.crt',
+          :ssl_key           => '/etc/pki/tls/private/httpd.key',
+          :ssl_ca            => '/etc/pki/tls/certs/ca.crt',
+          :ssl_verify_client => 'optional',
+          :root_url          => '',
         })
       end
 
@@ -374,11 +386,12 @@ describe 'horizon::wsgi::apache' do
     context 'with listen_ssl and ssl_redirect disabled' do
       before do
         params.merge!({
-          :listen_ssl   => true,
-          :ssl_redirect => false,
-          :horizon_cert => '/etc/pki/tls/certs/httpd.crt',
-          :horizon_key  => '/etc/pki/tls/private/httpd.key',
-          :horizon_ca   => '/etc/pki/tls/certs/ca.crt',
+          :listen_ssl        => true,
+          :ssl_redirect      => false,
+          :ssl_cert          => '/etc/pki/tls/certs/httpd.crt',
+          :ssl_key           => '/etc/pki/tls/private/httpd.key',
+          :ssl_ca            => '/etc/pki/tls/certs/ca.crt',
+          :ssl_verify_client => 'optional',
         })
       end
 
@@ -396,12 +409,13 @@ describe 'horizon::wsgi::apache' do
     context 'with listen_ssl and ssl_redirect disabled with custom root_url' do
       before do
         params.merge!({
-          :listen_ssl   => true,
-          :ssl_redirect => false,
-          :horizon_cert => '/etc/pki/tls/certs/httpd.crt',
-          :horizon_key  => '/etc/pki/tls/private/httpd.key',
-          :horizon_ca   => '/etc/pki/tls/certs/ca.crt',
-          :root_url     => '/custom',
+          :listen_ssl        => true,
+          :ssl_redirect      => false,
+          :ssl_cert          => '/etc/pki/tls/certs/httpd.crt',
+          :ssl_key           => '/etc/pki/tls/private/httpd.key',
+          :ssl_ca            => '/etc/pki/tls/certs/ca.crt',
+          :ssl_verify_client => 'optional',
+          :root_url          => '/custom',
         })
       end
 
@@ -522,36 +536,21 @@ describe 'horizon::wsgi::apache' do
         when 'Debian'
           case facts[:operatingsystem]
           when 'Debian'
-            { :http_service      => 'apache2',
-              :httpd_config_file => '/etc/apache2/sites-available/openstack-dashboard-alias-only.conf',
+            { :httpd_config_file => '/etc/apache2/sites-available/openstack-dashboard-alias-only.conf',
               :root_url          => '/horizon',
-              :apache_user       => 'www-data',
-              :apache_group      => 'www-data',
               :wsgi_user         => 'horizon',
-              :wsgi_group        => 'horizon',
-              :unix_user         => 'horizon',
-              :unix_group        => 'horizon' }
+              :wsgi_group        => 'horizon' }
           when 'Ubuntu'
-            { :http_service      => 'apache2',
-              :httpd_config_file => '/etc/apache2/conf-available/openstack-dashboard.conf',
+            { :httpd_config_file => '/etc/apache2/conf-available/openstack-dashboard.conf',
               :root_url          => '/horizon',
-              :apache_user       => 'www-data',
-              :apache_group      => 'www-data',
               :wsgi_user         => 'horizon',
-              :wsgi_group        => 'horizon',
-              :unix_user         => 'horizon',
-              :unix_group        => 'horizon' }
+              :wsgi_group        => 'horizon' }
           end
         when 'RedHat'
-          { :http_service      => 'httpd',
-            :httpd_config_file => '/etc/httpd/conf.d/openstack-dashboard.conf',
+          { :httpd_config_file => '/etc/httpd/conf.d/openstack-dashboard.conf',
             :root_url          => '/dashboard',
-            :apache_user       => 'apache',
-            :apache_group      => 'apache',
             :wsgi_user         => 'apache',
-            :wsgi_group        => 'apache',
-            :unix_user         => 'apache',
-            :unix_group        => 'apache' }
+            :wsgi_group        => 'apache' }
         end
       end
 
